require 'gosu'

class MenuItem
  def initialize(x, y, window)
    @x = x
    @y = y
    @window = window
    @selected = false
  end

  def button_down(id)
    on_enter if [Gosu::KB_ENTER, 40].include?(id) # 40 = big enter
  end

  def unselect
    @selected = false
  end

  def select
    @selected = true
  end

  def on_enter; end

  def draw
    @window.font.draw_text(@text.to_s, @x, @y, ZOrder::UI, 1.0, 1.0, @selected ? Gosu::Color::RED : Gosu::Color::YELLOW)
  end
end

class NewGame < MenuItem
  def initialize(x, y, window)
    super(x, y, window)
    @text = 'New Game'
  end

  def on_enter
    @window.new_game
  end
end

class Continue < MenuItem
  def initialize(x, y, window)
    super(x, y, window)
    @text = 'Continue'
  end

  def on_enter
    @window.continue
  end
end

class HighScore < MenuItem
  def initialize(x, y, window)
    super(x, y, window)
    @text = 'High Score'
  end

  def on_enter
    @window.high_score
  end
end

class Quit < MenuItem
  def initialize(x, y, window)
    super(x, y, window)
    @text = 'Quit'
  end

  def on_enter
    @window.close
  end
end

class Difficulty < MenuItem
  MAX_DIFFICULTY = 10

  attr_reader :difficulty

  def initialize(x, y, window)
    super(x, y, window)
    @difficulty = 0
    update_text
  end

  def button_down(id)
    case id
    when Gosu::KB_LEFT
      change_difficulty(-1)
    when Gosu::KB_RIGHT
      change_difficulty(1)
    else
      super
    end
  end

  def change_difficulty(direction)
    if direction.positive?
      @difficulty += 1 if @difficulty < MAX_DIFFICULTY
    elsif @difficulty.positive?
      @difficulty -= 1
    end
    update_text
  end

  def update_text
    @text = "Difficulty: #{@difficulty.zero? ? 'Dynamic' : @difficulty}"
  end
end
