class Player

  attr_accessor :x, :y
  attr_reader :color

  def initialize(x, y)
    @x = x
    @y = y
    @color = Gosu::Color::BLACK
    @data = nil
  end

  def is_brick(x, y)
    raise 'Error player bounds' if x.negative? || x > width - 1 || y.negative? || y > height - 1

    @data[y][x] == 1
  end

  def width
    @data[0].size
  end

  def height
    @data.size
  end

  def rotate
    @data = @data.reverse.transpose
  end

  def rotate_rollback
    @data = @data.transpose.reverse
  end
end

class Triangle < Player
  def initialize(x, y)
    super(x, y)
    @color = Gosu::Color::BLUE
    @data = [[0, 1, 0],
             [1, 1, 1]]
  end

end

class Square < Player
  def initialize(x, y)
    super(x, y)
    @color = Gosu::Color::RED
    @data = [[1, 1],
             [1, 1]]
  end
end

class El < Player
  def initialize(x, y)
    super(x, y)
    @color = Gosu::Color::YELLOW
    @data = [[1, 1, 1],
             [1, 0, 0]]
  end
end

class ElTwo < Player
  def initialize(x, y)
    super(x, y)
    @color = Gosu::Color.argb(0xFF, 0xFF, 0xA5, 0x00)
    @data = [[1, 0, 0],
             [1, 1, 1]]
  end
end

class Tower < Player
  def initialize(x, y)
    super(x, y)
    @color = Gosu::Color::FUCHSIA
    @data = [[1, 1, 1, 1]]
  end
end

class Zet < Player
  def initialize(x, y)
    super(x, y)
    @color = Gosu::Color::GREEN
    @data = [[1, 1, 0],
             [0, 1, 1]]
  end
end


class ZetTwo < Player
  def initialize(x, y)
    super(x, y)
    @color = Gosu::Color::CYAN
    @data = [[0, 1, 1],
             [1, 1, 0]]
  end
end

